@@ -41,14 +41,20 @@ TrackView::TrackView(Spotify::Session* pSession, QWidget* parent) :
 
 TrackView::~TrackView()
 {
+}
 
+void TrackView::closeEvent(QCloseEvent* evt)
+{
+    //Notification received when view closed
+    Q_UNUSED(evt);
+    m_pQueueView->setActive(false);
+    emit activeQueueViewChanged(false); //notify about change (set the active queueview instance to MainWindow owned)
 }
 
 void TrackView::setPlaylist(Spotify::Playlist* pPlaylist)
 {
     //set the playlist for which tracks should be displayed
 
-
 	if(pPlaylist)
         {
             m_pPlaylist = pPlaylist;
@@ -150,6 +156,8 @@ void TrackView::setPlayQueue()
     if(m_pQueueView)
     {
         m_pQueueView->setNowPlaying(PlayQueue,0,true);
+        m_pQueueView->setActive(true);
+        emit activeQueueViewChanged(true); //notify about active queue view change
         m_pQueueView->show();
     }
 }
