@@ -10,6 +10,7 @@
 #include <QTableWidgetItem>
 #include <QStringList>
 #include <QDebug>
+#include <QCloseEvent>
 #include <QMaemo5InformationBox>
 #include <QHeaderView>
 #include <QScrollBar>
@@ -40,6 +41,10 @@ public:
     void setPlaylist(Spotify::Playlist* pPlaylist); //set the playlist for which tracks should be displayed
     void setSearchResults(Spotify::Search* pSearch); //set the search results to be displayed
 
+protected:
+
+    void closeEvent(QCloseEvent* evt);
+
 private:
 
     QWidget m_MainLayout;
@@ -77,6 +82,7 @@ signals:
 
     void playQueueSet(QList<Spotify::Track*>); //signal emitted upon playqueue set
     void playQueuePosUpdated(qint32); //signal emitted when position in playqueue has been updated
+    void activeQueueViewChanged(bool); //signal emitted when active queueview changed (param is TRUE in case TrackView instance is active)
 };
 
 #endif // TRACKVIEW_H
