@@ -16,16 +16,29 @@ MainWindow::MainWindow(QWidget *parent)
 
     m_pAppSettings = new QSettings("qspot","qspot", this);
 
-    m_pLoginDlg = new LoginDialog(m_pSession,m_pAppSettings,this);
+    m_pLoginDlg = new LoginDialog(m_pSession,m_pAppSettings,this); //allocate login dialog instance
+
+    m_pSettingsDlg = new SettingsDialog(m_pAppSettings,this); //allocate settings dialog instance
 
     //set up the the main window menu
 
     menuBar()->addAction(tr("Settings"));
     menuBar()->addAction(tr("About"));
 
-     //setup signals etc.
+    //setup the app About dialog box
+
+    QPixmap appIconMap;
+    appIconMap.load("/usr/share/icons/hicolor/64x64/apps/qspot.png"); //load application icon from file
+
+    m_AboutDlg.setIconPixmap(appIconMap);
+    m_AboutDlg.setWindowTitle(tr("About QSpot")),
+    m_AboutDlg.setText(tr("An open-source Qt-based Spotify client for the N900/Maemo5 (based on libopenspotify).\n\n(C) 2010 Andreas Enbacka and the QSpot Team.\n\n"
+                          "Special thanks to Markus (markusm@tmo) for assistance with the graphical design and layout."));
+
+     //setup signal / slot connections etc.
 
     connect(m_pLoginDlg,SIGNAL(rejected()),SLOT(OnLoginDialogRejected()));
+    connect(m_pSettingsDlg,SIGNAL(settingsSaved()),SLOT(OnSettingsSaved()));
     connect(m_pSession,SIGNAL(loggedIn(Spotify::Error)),SLOT(OnLoggedIn(Spotify::Error)));
     connect(m_pSession,SIGNAL(playlistContainersReady(QList<Spotify::Playlist*>)),this,SLOT(OnPlaylistContainersReady(QList<Spotify::Playlist*>)));
     connect(m_pSession,SIGNAL(playing(bool)),SLOT(OnPlayingState(bool)));
@@ -62,7 +75,7 @@ MainWindow::MainWindow(QWidget *parent)
     m_NowPlayingFont.setFamily(QApplication::font().family());
     m_NowPlayingFont.setPointSize(14);
     m_NowPlayingInfo.setFont(m_NowPlayingFont);
-    m_NowPlayingInfo.setFixedWidth(558);
+    m_NowPlayingInfo.setFixedWidth(510);
     m_NowPlayingInfo.setAlignment(Qt::AlignLeft|Qt::AlignVCenter);
     m_NowPlayingInfo.setText("----"); //default (empty) value for now playing info
     m_NowPlayingPositionInfo.setFont(m_NowPlayingFont);
@@ -74,7 +87,7 @@ MainWindow::MainWindow(QWidget *parent)
     m_GridLayout.addWidget(&m_PlaylistInfo,1,0,1,-1);
     m_GridLayout.addWidget(&m_NowPlayingIcon,2,0);
     m_GridLayout.addWidget(&m_NowPlayingInfo,2,1,1,1,Qt::AlignLeft);
-    m_GridLayout.addWidget(&m_NowPlayingPositionInfo,2,2,1,1,Qt::AlignLeft);
+    m_GridLayout.addWidget(&m_NowPlayingPositionInfo,2,2,1,1,Qt::AlignRight);
     m_GridLayout.addWidget(m_pSpectrum,2,3);
 
     m_MainLayout.setLayout(&m_GridLayout);
@@ -82,8 +95,10 @@ MainWindow::MainWindow(QWidget *parent)
     setCentralWidget(&m_MainLayout);
 
     m_pTrackView = new TrackView(m_pSession,this);
+
     connect(m_pTrackView,SIGNAL(playQueueSet(QList<Spotify::Track*>)),SLOT(OnSetPlayQueue(QList<Spotify::Track*>)));
     connect(m_pTrackView,SIGNAL(playQueuePosUpdated(qint32)),SLOT(OnPlayQueuePosUpdated(qint32)));
+    connect(m_pTrackView,SIGNAL(activeQueueViewChanged(bool)),SLOT(OnActiveQueueViewChanged(bool)));
 
     m_pQueueView = new QueueView(m_pSession,this);
     connect(m_pQueueView,SIGNAL(playQueuePosUpdated(qint32)),SLOT(OnPlayQueuePosUpdated(qint32)));
@@ -95,6 +110,23 @@ MainWindow::~MainWindow()
 {
 }
 
+void MainWindow::OnSettingsSaved()
+{
+    //called when app settings have been saved (modified)
+    m_pSession->setMinBufferSize(m_pAppSettings->value("QSpot/minBufferLen",MIN_BUFFER_LEN_DEFAULT).toInt()); //update min. buffer length (default to 30 secs)
+
+    if(m_pAppSettings->value("QSpot/preBufferingActive",PRE_BUFFERING_DEFAULT).toInt())
+    {
+        qDebug() << "1";
+        m_pSession->setPreBufferingActive(true);
+    }
+    else
+    {
+        qDebug() << "0";
+        m_pSession->setPreBufferingActive(false);
+    }
+}
+
 void MainWindow::OnShowLogin()
 {
   m_pLoginDlg->showMaximized(); //show the login dialog
@@ -121,6 +153,26 @@ void MainWindow::OnTrackPosUpdated(qint64 pos)
 
 }
 
+void MainWindow::OnActiveQueueViewChanged(bool active)
+{
+    //notification that active QueueView state has changed.
+    //If active is false, MainWindow owned QueueView instance should be active,
+    //else the TrackView owned is active.
+
+    if(active)
+    {
+        m_pQueueView->setActive(false);
+    }
+    else
+    {
+        if(m_PlayQueue.size()>0)
+        {
+            m_pQueueView->setNowPlaying(m_PlayQueue,m_currQueuePos,m_playing,m_currPlaybackPos,m_currBuffPos); //set queue (now playing) instance info
+            m_pQueueView->setActive(true);
+        }
+    }
+}
+
 void MainWindow::OnPlaybackPositionUpdated(qint64 pos)
 {
         //set current playback position, and update the track progress part of the now playing infobar
@@ -131,7 +183,7 @@ void MainWindow::OnPlaybackPositionUpdated(qint64 pos)
 
         QTextStream outStream(&strCurrTrackProgressInfo);
 
-        QTime currTrackPos(0,pos/60000,(pos/1000)%60,0);
+        QTime currTrackPos(pos/3600000,pos/60000,(pos/1000)%60,0);
 
         Spotify::Track* currTrack = m_PlayQueue.at(m_currQueuePos);
 
@@ -160,7 +212,7 @@ void MainWindow::OnNowPlaying()
     {
         if(m_pQueueView)
         {
-            m_pQueueView->setNowPlaying(m_PlayQueue,m_currQueuePos,m_playing,m_currPlaybackPos,m_currBuffPos); //set queue (now playing) view mode
+            m_pQueueView->setNowPlaying(m_PlayQueue,m_currQueuePos,m_playing,m_currPlaybackPos,m_currBuffPos); //set queue (now playing) instance info
             m_pQueueView->show();
         }
     }
@@ -174,10 +226,9 @@ void MainWindow::OnSetPlayQueue(QList<Spotify::Track*> queue)
 
 void MainWindow::OnPlayQueuePosUpdated(qint32 pos)
 {
-     m_currQueuePos = pos;
-
-     if(m_currQueuePos>=0)
+     if(pos>=0)
      {
+         m_currQueuePos = pos;
 
          Spotify::Track* currTrack = m_PlayQueue.at(m_currQueuePos);
 
@@ -194,6 +245,7 @@ void MainWindow::OnPlayQueuePosUpdated(qint32 pos)
      }
      else //empty now playing infobar (when playqueue has reached end)
      {
+        m_currQueuePos = -1;
         m_NowPlayingInfo.setText("----");
         m_NowPlayingPositionInfo.setText("");
      }
@@ -289,24 +341,44 @@ void MainWindow::OnMainMenuAction(QAction* action)
 {
 
   //User has selected an item from the app main menu
+
+    if(action->text()==tr("Settings"))
+    { //display the app Settings dialog
+        //display the Settings dialog
+        m_pSettingsDlg->readSettings();
+        m_pSettingsDlg->showMaximized();
+    }
+    else if(action->text()==tr("About"))
+    { //display the app About dialog
+        m_AboutDlg.exec();
+    }
 }
 
+
 void MainWindow::OnSearch()
 {
     //Search request
 
     Spotify::Error error;
+    int maxTracks, maxAlbums, maxArtists;
 
-    if(m_SearchInput.text().trimmed()!="")
+    if(m_pAppSettings)
     {
-        QMaemo5InformationBox::information(this,tr("Searching"));
-        setAttribute(Qt::WA_Maemo5ShowProgressIndicator,true); //display progress indicator
+        maxTracks = m_pAppSettings->value("QSpot/maxSearchTracks",MAX_TRACKS_DEFAULT).toInt();
+        maxAlbums = m_pAppSettings->value("QSpot/maxSearchAlbums",MAX_ALBUMS_DEFAULT).toInt();
+        maxArtists = m_pAppSettings->value("QSpot/maxSearchArtists",MAX_ARTISTS_DEFAULT).toInt();
 
-        error = m_pSession->search(m_SearchInput.text(),0,500,0,10,0,10,NULL);
-        if(error.isError())
-        { //some error occured
-            QMaemo5InformationBox::information(this,tr("Error: ") + error.toString());
-            setAttribute(Qt::WA_Maemo5ShowProgressIndicator,false); //hide progress indicator
+        if(m_SearchInput.text().trimmed()!="")
+        {
+            QMaemo5InformationBox::information(this,tr("Searching"));
+            setAttribute(Qt::WA_Maemo5ShowProgressIndicator,true); //display progress indicator
+
+            error = m_pSession->search(m_SearchInput.text(),0,maxTracks,0,maxAlbums,0,maxArtists,NULL);
+            if(error.isError())
+            { //some error occured
+                QMaemo5InformationBox::information(this,tr("Error: ") + error.toString());
+                setAttribute(Qt::WA_Maemo5ShowProgressIndicator,false); //hide progress indicator
+            }
         }
     }
 }
